From: Eric Sunshine Date: Wed, 10 Apr 2013 10:13:06 GMT Subject: Re: [PATCH v3 6/7] completion: get rid of __gitcomp_1 Message-ID: In-Reply-To: <1365577077-12648-7-git-send-email-felipe.contreras@gmail.com> On Wed, Apr 10, 2013 at 2:57 AM, Felipe Contreras wrote: > There's no point in calling a separate function that is only used in one > place. Specially considering that there's no need to call compgen, and s/Specially/Especially/ > we traverse the words ourselves both in __gitcompadd, and __gitcomp_1. s/ourselves/ourself/ > So lets squash the functions together, and traverse only once. s/lets/let's/ > This improves performance. For N number of words: > > == 1 == > original: 0.002s > new: 0.000s > == 10 == > original: 0.005s > new: 0.001s > == 100 == > original: 0.009s > new: 0.006s > == 1000 == > original: 0.027s > new: 0.019s > == 10000 == > original: 0.163s > new: 0.151s > == 100000 == > original: 1.555s > new: 1.497s > > No functional changes. > > Signed-off-by: Felipe Contreras